guix_mirror_bot pushed a commit to branch master
in repository guix.

commit 50da018c8c177876d8032cb4cfb118615224745d
Author: Orahcio Felício de Sousa <[email protected]>
AuthorDate: Fri Jul 3 13:21:29 2026 -0300

    gnu: xournalpp: Fix gtksourceview resources.
    
    * gnu/packages/pdf.scm (xournalpp)[arguments]: Update wrap-gdk-pixbuf
    phase to include gtksourceview-4 share directory in XDG_DATA_DIRS.
    [inputs]: Add bash-minimal for the wrap-program.
    
    Change-Id: I7995b749760b432878f9db08186bab025ecfb8d2
    Signed-off-by: Ludovic Courtès <[email protected]>
    Merges: #9691
---
 gnu/packages/pdf.scm | 15 +++++++++++----
 1 file changed, 11 insertions(+), 4 deletions(-)

diff --git a/gnu/packages/pdf.scm b/gnu/packages/pdf.scm
index 32c06f5a14..0a2d60f6c9 100644
--- a/gnu/packages/pdf.scm
+++ b/gnu/packages/pdf.scm
@@ -1403,11 +1403,17 @@ using a stylus.")
             (assoc-ref glib-or-gtk:%standard-phases
                        'generate-gdk-pixbuf-loaders-cache-file))
           (add-after 'glib-or-gtk-wrap 'wrap-gdk-pixbuf
-            ;; This phase is necessary for xournalpp to load SVG icons.
-            (lambda _
-              (let ((pixbuf-module-file (getenv "GDK_PIXBUF_MODULE_FILE")))
+            ;; This phase is necessary for xournalpp to load SVG icons and
+            ;; access gtksourceview-4/styles.
+            (lambda* (#:key inputs #:allow-other-keys)
+              (let ((pixbuf-module-file (getenv "GDK_PIXBUF_MODULE_FILE"))
+                    (gtksourceview-4-resources
+                     (dirname
+                      (search-input-directory inputs 
"share/gtksourceview-4"))))
                 (wrap-program (string-append #$output "/bin/xournalpp")
-                  `("GDK_PIXBUF_MODULE_FILE" = (,pixbuf-module-file)))))))))
+                  `("GDK_PIXBUF_MODULE_FILE" = (,pixbuf-module-file))
+                  `("XDG_DATA_DIRS" ":" prefix
+                    (,gtksourceview-4-resources)))))))))
     (native-inputs
      (list cppunit
            gettext-minimal
@@ -1419,6 +1425,7 @@ using a stylus.")
     (inputs
      (list adwaita-icon-theme
            alsa-lib
+           bash-minimal
            gtk+
            gtksourceview-4
            (librsvg-for-system)

Reply via email to